@@ -1,7 +1,7 @@
 /*
  hstr.c     BASH history completion utility
 
- Copyright (C) 2014-2016 Martin Dvorak <martin.dvorak@mindforger.com>
+ Copyright (C) 2014-2018 Martin Dvorak <martin.dvorak@mindforger.com>
 
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
@@ -22,6 +22,8 @@
 #include <locale.h>
 #ifdef __APPLE__
 #include <curses.h>
+#elif defined(__FreeBSD__)
+#include <ncurses.h>
 #else
 #include <ncursesw/curses.h>
 #endif
@@ -101,6 +103,7 @@
 #define HH_CONFIG_KEYWORDS   "keywords"
 #define HH_CONFIG_SORTING    "rawhistory"
 #define HH_CONFIG_FAVORITES  "favorites"
+#define HH_CONFIG_NOCONFIRM  "noconfirm"
 // MVP: model is the same regardless prompt is top or bottom - view is different
 #define HH_CONFIG_PROMPT_BOTTOM "prompt-bottom"
 #define HH_CONFIG_BLACKLIST  "blacklist"
@@ -233,8 +236,7 @@ static const char *HELP_STRING=
         "\n";
 
 static const char *VERSION_STRING=
-        "hh version \"1.23\""
-        "\n   build   \""__DATE__" " __TIME__"\""
+        "hh version \"1.24\" (2018-01-03T12:19:00)"
         "\n";
 
 // TODO help screen - curses window (tig)
@@ -273,6 +275,7 @@ typedef struct {
 
     unsigned char theme;
     bool keepPage; // do NOT clear page w/ selection on HH exit
+    bool noConfirm; // do NOT ask for confirmation on history entry delete
     int bigKeys;
     int debugLevel;
 
@@ -382,6 +385,9 @@ void hstr_get_env_configuration(Hstr *hstr)
         if(strstr(hstr_config,HH_CONFIG_KEEP_PAGE)) {
             hstr->keepPage=true;
         }
+        if(strstr(hstr_config,HH_CONFIG_NOCONFIRM)) {
+            hstr->noConfirm=true;
+        }
 
         if(strstr(hstr_config,HH_CONFIG_DEBUG)) {
             hstr->debugLevel=HH_DEBUG_LEVEL_DEBUG;
@@ -1056,9 +1062,11 @@ void loop_to_select(Hstr *hstr)
                 msg=malloc(strlen(delete)+1);
                 strcpy(msg,delete);
 
-                print_confirm_delete(msg, hstr);
-                cc = wgetch(stdscr);
-                if(cc == 'y') {
+                if(!hstr->noConfirm) {
+                    print_confirm_delete(msg, hstr);
+                    cc = wgetch(stdscr);
+                }
+                if(hstr->noConfirm || cc == 'y') {
                     deletedOccurences=remove_from_history_model(msg, hstr);
                     result=hstr_print_selection(maxHistoryItems, pattern, hstr);
                     print_cmd_deleted_label(msg, deletedOccurences, hstr);
